@@ -1,4 +1,4 @@
-#%% begin initialize postgis-1.3.3-i586-P1
+#%% begin initialize postgis-1.3.5-i586-P1
 VER=1.3
 /bin/chown postgres.pgsql $ROOT/./opt/pgsql/lib/liblwgeom.so.$VER
 /bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis.sql
@@ -21,6 +21,15 @@ VER=1.3
 ( cd $ROOT/./opt/pgsql/lib ; ln -sf liblwgeom.so.$VER liblwgeom.so.1 )
 ( cd $ROOT/./opt/pgsql/lib ; rm -rf liblwgeom.so )
 ( cd $ROOT/./opt/pgsql/lib ; ln -sf liblwgeom.so.1 liblwgeom.so )
+/bin/chown postgres.pgsql $ROOT/./opt/pgsql/lib/liblwgeom.*
+/bin/chown postgres.pgsql $ROOT/./opt/pgsql/*
+/bin/chown postgres.pgsql $ROOT/./opt/pgsql/.
 
-/bin/su - postgres -c "$ROOT/./opt/pgsql/share/contrib/lwpostgis-install.sh"
+A=`/bin/su - postgres -c "psql -t -c \"SELECT relname FROM pg_catalog.pg_class where relname = 'geometry_columns'\""`
+
+if [ "$A" = "geometry_columns" ]; then
+  /bin/su - postgres -c "$ROOT/./opt/pgsql/share/contrib/lwpostgis-upgrade.sh"
+else
+  /bin/su - postgres -c "$ROOT/./opt/pgsql/share/contrib/lwpostgis-install.sh"
+fi
 #%% end
